Alpaca-style action frame whose channel names are top-level keys.
Pre-formatted channels use channel:symbol, for example
trades:FAKEPACA. Channels with the same name are grouped into one list.
Alpaca-style action frame whose channel names are top-level keys.
Pre-formatted channels use channel:symbol, for example
trades:FAKEPACA. Channels with the same name are grouped into one list.